pawl(target, binning, AP, proposal, verbose)target: specifies the target distribution.
See the help of target. If the target is discrete, target must contain the slots dproposal, rproposal and proposalparam that specify the proposal kernel in the Metropolis-Hastings step. Otherwise the default is an adaptive gaussian random walk.
binning, defining the initial bins used by the Wang-Landau algorithm.
The binning object also contains some parameters specifying if the automatic binning mechanism is active or not, for instance.
tuningparameters: specifies the number of chains, the number
of iterations, and what should be stored during along the run. See the help of tuningparameters.
"logical": if TRUE (default) then prints some indication of progress
in the console.
"names(results)" where "results" is the output
of the function.
adaptiveMH, binning